# -*- encoding: utf-8 -*-

from .formatter import formatter


class figure:
    """ Class representing a latex figure. """

    fmt = formatter({
        'content': """\\begin{{figure}}[{options}]
{centered}
{inner}
\\end{{figure}}"""
    })

    def __init__(self, inner, options='!h', centered=True):
        """ Create a figure with given options.

        Parameters:
          - options Options for the figure.
          - centered Set to true to add a centering command.
        """
        self.inner = inner
        self.options = options
        self.centered = ''
        if centered:
            self.centered = '\\centering'

    def __str__(self):
        return self.fmt.format('content', {
            'options': self.options,
            'centered': self.centered,
            'inner': self.inner
        })
