# -*- encoding: utf-8 -*-

from .formatter import formatter


class makebox:
    """ Class representing an unindented makebox. """

    fmt = formatter({
        'content': """{noindent}\\makebox[{width}]{{
{inner}
}}"""
    })

    def __init__(self, inner, width=None, noindent=True):
        """ Create a new makebox with given width.

        Parameters:
          - width Width of the box (string, float, or None). If float,
            represent a percentage of \\textwidth. None is used to have
            \\textwidth.
          - noindent Add a \\noindent command before the box.
        """
        self.inner = inner

        self.width = width
        if self.width is None:
            self.width = '\\textwidth'
        elif type(self.width) != 'str':
            self.width = '{}\\textwidth'.format(self.width)

        self.noindent = ''
        if self.noindent:
            self.noindent = '\\noindent'

    def __str__(self):
        return self.fmt.format('content', {
            'inner': self.inner,
            'width': self.width,
            'noindent': self.noindent
        })
