# -*- encoding: utf-8 -*-

from .formatter import formatter


class tabular:
    """ Class representing a latex tabular. """

    fmt = formatter({
        'content': """\\begin{{tabular}}{{{columns}}}
{inner}
\\end{{tabular}}"""
    })

    def __init__(self, rows, columns=None):
        """ Create a tabular with given rows and column specification.

        Parameters:
          - rows Rows for the tabular (list of list or list of string).
          - columns String representing columns.

        If `rows` is a str, an empty tabular is created and `rows` is used
        instead of `columns` for the columns specification.
        """
        if type(rows) == str:
            columns = rows
            rows = []
        self.columns = columns
        self.rows = []
        for row in rows:
            self.addrow(row)

    def addrow(self, row):
        """ Add a row to the tabular.

        Parameters:
          - row Array or string (array will be joined with ' & ').
        """
        if type(row) != 'str':
            row = ' & '.join(map(str, row))
        self.rows.append(row)

    def addrows(self, rows):
        """ Add multiple rows to the tabular (see addrow). """
        for row in rows:
            self.addrow(row)

    def __str__(self):
        inner = '\\\\\n'.join(self.rows)
        return self.fmt.format('content', {
            'columns': self.columns,
            'inner': inner
        })
